#!/opt/python-init/bin/python

# Ez a python osztaly a HTML Table konstrukcio Objektum-orientlt
# megfeleloje. Egy mukodo rendszer resze, segitsegevel konnyden lehet generalni HTML 
# tablakat.

class HeadlineTable:
    #A Head osztalyban egy objaktumaban taroljuk egy adott tabla Head (<th>)
    #reszeit
    class Head:
        def __init__(self):
            self.names = []
        def add(self, name):
            self.names.append(name)

    #A Row osztaly egy peldanya a tabla egy sorat reprezentalja majd.
    class Row:
        #Ket peldanyvaltozot inicializalunk: 
        #    - a fields trolja a mezok ertekeit
        #    - a styles trolja az adott mezo sorszamhoz a stlus stringet
        #      (az elso mezoelem sorszama 0)
        def __init__(self):
            self.fields = []
            self.styles = {}
        
        #A metodus hozzaad egy uj mezot a mezolistahoz, illetve a mezo sorszamahoz 
        #beallitja a style-t, ha az nem None.
        def add(self, field, style=None):
            if style is not None:
                self.styles[len(self.fields)] = style
            self.fields.append(field)
    
    #A tablat inicializalo metodus.
    #A sorokat tartalmazo listat ures listaval inicializaljuk, majd a kiegeszito informaciokat
    #eltaroljuk.
    def __init__(self, header, divstyle=None, tabstyle="width: 60%; height: auto;", tabclass=None, headerstyle=None):
        self.rows = []
        self.header = header
        self.divstyle = divstyle
        self.tabstyle = tabstyle
        self.tabclass = tabclass
        self.headerstyle = headerstyle
        self.head = HeadlineTable.Head()
    
    def add(self, row):
        self.rows.append(row)
    
    #A print meghivasakor ez a fuggveny hivodik meg, amely eloallitja a Headlinetable objektum 
    # HTML szoveges reprezentaciojat.
    def __str__(self):
        retstr = []
        if self.divstyle is None:
            retstr.append("<div>")
        else:
            retstr.append("<div style=\"%s\">" % (self.divstyle))
        if self.headerstyle is None:
            retstr.append("  <h2 class=\"overview\">%s</h2>" % (self.header))
        else:
            retstr.append("  <h2 style=\"%s\" class=\"overview\">%s</h2>" % (self.headerstyle, self.header))
        if self.tabclass is None:
            retstr.append("  <table style=\"%s\">" % (self.tabstyle))
        else:
            retstr.append("  <table class=\"%s\" style=\"%s\">" % (self.tabclass, self.tabstyle))
        retstr.append("    <thead>")
        retstr.append("      <tr>")
        for h in self.head.names:
            retstr.append("        <th>%s</th>" % (h))
        retstr.append("      </tr>")
        retstr.append("    </thead>")
        retstr.append("    <tbody>")
        for row in self.rows:
            retstr.append("      <tr>")
            for (i, field) in enumerate(row.fields):
                if i in row.styles:
                    retstr.append("        <td style=\"%s\">%s</td>" % (row.styles[i], field))
                else:
                    retstr.append("        <td>%s</td>" % (field))
            retstr.append("      </tr>")
        retstr.append("    </tbody>")
        retstr.append("  </table>")
        retstr.append("</div>")
        return "\n".join(retstr)

        

#Hasznalat:

table = HeadlineTable("Users", divstyle="clear: both; margin-top: 30px;",
                          tabclass="sortable", tabstyle="width: 100%; height: auto;", headerstyle="margin-left: 40%")
table.head.add("EHA")
table.head.add("Nev")
table.head.add("Kor")

row = HeadlineTable.Row()
row.add("SOBNABB")
row.add("Somhegyi Benjamin")
row.add(24)
table.add(row)

row = HeadlineTable.Row()
row.add("BOBOABI")
row.add("Bozsogi Balazs")
row.add(23)
table.add(row)

print table
